"""
scyjava Converters for converting Java enums to their autogenerated Python enum
"""
from enum import Enum

from napari_imagej.java import jc
from napari_imagej.types.converters import java_to_py_converter, py_to_java_converter
from napari_imagej.types.enums import _is_autogenerated_enum, py_enum_for


@py_to_java_converter(predicate=_is_autogenerated_enum)
def _py_enum_to_java_enum(obj: Enum) -> "jc.Enum":
    """Converts an autogenerated Python Enum into a Java Enum"""
    return obj.value


@java_to_py_converter(
    predicate=lambda obj: hasattr(obj, "getClass") and py_enum_for(obj.getClass())
)
def _java_enum_to_py_enum(obj: "jc.Enum") -> Enum:
    """Converts a Java Enum into an AUTOGENERATED Python Enum"""
    py_enum = py_enum_for(obj.getClass())
    for e in py_enum:
        if e.value == obj:
            return e
