from typing import Dict

from napari.utils import progress

from napari_imagej.java import jc


class ModuleProgressManager:
    """Generates and updates progress bars for SciJava Modules
    The progress bars generated by this class have three checkpoints:

    1. Preprocessing completed
    2. Processing completed
    3. Postprocessing completed

    update_progress(module) should be called after each of these stages
    are complete for Module module.

    init_progress(module) is provided as a separate function, and must be
    called from the GUI thread before update_progress is called.
    """

    def __init__(self):
        self.prog_bars: Dict[jc.Module, progress] = {}

    def init_progress(self, module: "jc.Module"):
        prog = progress(
            desc=str(module.getInfo().getTitle()),
            total=3,
        )
        self.prog_bars[module] = prog

    def update_progress(self, module: "jc.Module"):
        if pbr := self.prog_bars.get(module):
            pbr.update()

    def close(self, module: "jc.Module"):
        if pbr := self.prog_bars.pop(module, None):
            pbr.close()


pm = ModuleProgressManager()
